@@ -5,7 +5,7 @@ use strict;
 use Carp;
 use Scalar::Util qw( blessed );
 
-use version; our $VERSION = qv( '0.0.4' );
+use version; our $VERSION = qv( '0.0.5' );
 
 use overload (
     '""'  => \&stringify,
@@ -61,7 +61,7 @@ BEGIN {
         *$inc_func = sub {
             my $self = shift;
             return $self->increment( $field );
-          }
+        };
     }
 }
 
@@ -355,6 +355,18 @@ sub increment {
     }
 }
 
+sub set {
+    my $self  = shift;
+    my $other = shift;
+
+    $other = __PACKAGE__->new( $other ) unless ref $other;
+
+    my @comp = $other->components;
+
+    $self->components( \@comp );
+    $self->alpha( $other->alpha );
+}
+
 1;
 __END__
 
@@ -364,7 +376,7 @@ Perl::Version - Parse and manipulate Perl version strings
 
 =head1 VERSION
 
-This document describes Perl::Version version 0.0.4
+This document describes Perl::Version version 0.0.5
 
 =head1 SYNOPSIS
 
@@ -777,6 +789,19 @@ Get or set the alpha component of a version. Returns 0 for versions with no alph
 
 Return true if a version has a non-zero alpha component.
 
+=item C<< set >>
+
+Set the version to match another version preserving the formatting of this version.
+
+    $version->set( $other_version );
+
+You may also set the version from a literal string:
+
+    $version->set( '1.2.3' );
+
+The version will be updated to the value of the version string but will
+retain its current formatting.
+
 =back
 
 =head2 Incrementing
